==> geant4.11.0_11.0.3-0%2B13.1.tar.gz: BUILD/source/materials/sources.cmake <==
# - G4materials module build definition

geant4_add_module(G4materials
  PUBLIC_HEADERS
		G4AtomicBond.hh
		G4AtomicFormFactor.hh
		G4AtomicShells.hh
		G4AtomicShells_XDB_EADL.hh
		G4CrystalAtomBase.hh
		G4CrystalBravaisLattices.h
		G4CrystalLatticeSystems.h
		G4CrystalExtension.hh
		G4CrystalUnitCell.hh
		G4DensityEffectCalculator.hh
		G4DensityEffectData.hh
		G4ElementData.hh
		G4Element.hh
		G4ElementTable.hh
		G4ElementVector.hh
		G4ExtDEDXTable.hh
		G4ExtendedMaterial.hh
		G4ICRU90StoppingData.hh
		G4IonisParamElm.hh
		G4IonisParamMat.hh
		G4IonStoppingData.hh
		G4Isotope.hh
		G4IsotopeVector.hh
		G4LatticeLogical.hh
		G4LatticePhysical.hh
		G4Material.hh
    G4MaterialPropertiesIndex.hh
		G4MaterialPropertiesTable.hh
		G4MaterialPropertyVector.hh
		G4MaterialTable.hh
    G4MicroElecMaterialStructure.hh
    G4MicroElecSiStructure.hh
		G4NistElementBuilder.hh
		G4NistManager.hh
		G4NistMaterialBuilder.hh
		G4NistMessenger.hh
		G4OpticalMaterialProperties.hh
		G4OpticalSurface.hh
		G4SandiaTable.hh
		G4StaticSandiaData.hh
		G4SurfaceProperty.hh
		G4UCNMaterialPropertiesTable.hh
		G4UCNMicroRoughnessHelper.hh
		G4VIonDEDXTable.hh
		G4VMaterialExtension.hh
  SOURCES
		G4AtomicBond.cc
		G4AtomicFormFactor.cc
		G4AtomicShells.cc
		G4AtomicShells_XDB_EADL.cc
		G4CrystalExtension.cc
		G4CrystalUnitCell.cc
		G4DensityEffectCalculator.cc
		G4DensityEffectData.cc
		G4Element.cc
		G4ElementData.cc
		G4ExtDEDXTable.cc
		G4ExtendedMaterial.cc
		G4ICRU90StoppingData.cc
		G4IonisParamElm.cc
		G4IonisParamMat.cc
		G4IonStoppingData.cc
		G4Isotope.cc
		G4LatticeLogical.cc
		G4LatticePhysical.cc
		G4Material.cc
		G4MaterialPropertiesTable.cc
    G4MicroElecMaterialStructure.cc
    G4MicroElecSiStructure.cc
		G4NistElementBuilder.cc
		G4NistManager.cc
		G4NistMaterialBuilder.cc
		G4NistMessenger.cc
		G4OpticalSurface.cc
		G4SandiaTable.cc
		G4SurfaceProperty.cc
		G4UCNMaterialPropertiesTable.cc
		G4UCNMicroRoughnessHelper.cc
		G4VIonDEDXTable.cc)

geant4_module_link_libraries(G4materials
  PUBLIC
	  G4globman
		G4intercoms
  PRIVATE
    ${ZLIB_LIBRARIES})

==> geant4.11.1_11.1.0-0%2B2.1.tar.gz: BUILD/source/materials/sources.cmake <==
# - G4materials module build definition

geant4_add_module(G4materials
  PUBLIC_HEADERS
		G4AtomicBond.hh
		G4AtomicFormFactor.hh
		G4AtomicShells.hh
		G4AtomicShells_XDB_EADL.hh
		G4CrystalAtomBase.hh
		G4CrystalBravaisLattices.h
		G4CrystalLatticeSystems.h
		G4CrystalExtension.hh
		G4CrystalUnitCell.hh
		G4DensityEffectCalculator.hh
		G4DensityEffectData.hh
		G4ElementData.hh
		G4Element.hh
		G4ElementTable.hh
		G4ElementVector.hh
		G4ExtDEDXTable.hh
		G4ExtendedMaterial.hh
		G4ICRU90StoppingData.hh
		G4IonisParamElm.hh
		G4IonisParamMat.hh
		G4IonStoppingData.hh
		G4Isotope.hh
		G4IsotopeVector.hh
		G4LatticeLogical.hh
		G4LatticePhysical.hh
		G4Material.hh
    G4MaterialPropertiesIndex.hh
		G4MaterialPropertiesTable.hh
		G4MaterialPropertyVector.hh
		G4MaterialTable.hh
    G4MicroElecMaterialStructure.hh
    G4MicroElecSiStructure.hh
		G4NistElementBuilder.hh
		G4NistManager.hh
		G4NistMaterialBuilder.hh
		G4NistMessenger.hh
		G4OpticalMaterialProperties.hh
		G4OpticalSurface.hh
		G4SandiaTable.hh
		G4StaticSandiaData.hh
		G4SurfaceProperty.hh
		G4UCNMaterialPropertiesTable.hh
		G4UCNMicroRoughnessHelper.hh
		G4VIonDEDXTable.hh
		G4VMaterialExtension.hh
  SOURCES
		G4AtomicBond.cc
		G4AtomicFormFactor.cc
		G4AtomicShells.cc
		G4AtomicShells_XDB_EADL.cc
		G4CrystalExtension.cc
		G4CrystalUnitCell.cc
		G4DensityEffectCalculator.cc
		G4DensityEffectData.cc
		G4Element.cc
		G4ElementData.cc
		G4ExtDEDXTable.cc
		G4ExtendedMaterial.cc
		G4ICRU90StoppingData.cc
		G4IonisParamElm.cc
		G4IonisParamMat.cc
		G4IonStoppingData.cc
		G4Isotope.cc
		G4LatticeLogical.cc
		G4LatticePhysical.cc
		G4Material.cc
		G4MaterialPropertiesTable.cc
    G4MicroElecMaterialStructure.cc
    G4MicroElecSiStructure.cc
		G4NistElementBuilder.cc
		G4NistManager.cc
		G4NistMaterialBuilder.cc
		G4NistMessenger.cc
		G4OpticalSurface.cc
		G4SandiaTable.cc
		G4SurfaceProperty.cc
		G4UCNMaterialPropertiesTable.cc
		G4UCNMicroRoughnessHelper.cc)

geant4_module_link_libraries(G4materials
  PUBLIC
	  G4globman
		G4intercoms
  PRIVATE
    ${ZLIB_LIBRARIES})
